Processor.App.Downloader.downloader.Downloader
==============================================

.. currentmodule:: Processor.App.Downloader.downloader

.. autoclass:: Downloader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~Downloader.__init__
      ~Downloader.download
   
   

   
   
   